Documentation
¶
Overview ¶
Package greenhouse provides a wrapper around the greenhouse.io Job Board API. The API is defined at: https://developers.greenhouse.io/job-board.html
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Board ¶
Board describes an organization's job board. Usually it includes a company name and sometimes a description of the organization as html.
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
A Client manages communication with the Greenhouse API.
func (*Client) Board ¶
Board returns the organization's name and optionally an html description of the organization.
type Jobs ¶
type Jobs struct {
Jobs []struct {
ID int `json:"id"`
InternalJobID int `json:"internal_job_id"`
Title string `json:"title"`
Education string `json:"education,omitempty"`
UpdatedAt string `json:"updated_at"`
Location struct {
Name string `json:"name"`
} `json:"location"`
AbsoluteURL string `json:"absolute_url"`
// TODO: varies by company, some use []string for Value, some
// use string
// Metadata []struct {
// ID int `json:"id"`
// Name string `json:"name"`
// Value []string `json:"value"`
// ValueType string `json:"value_type"`
// } `json:"metadata"`
Content string `json:"content"`
Departments []struct {
ID int `json:"id"`
Name string `json:"name"`
ChildIds []int `json:"child_ids"`
ParentID int `json:"parent_id"`
} `json:"departments"`
Offices []struct {
ID int `json:"id"`
Name string `json:"name"`
Location string `json:"location"`
ChildIds []int `json:"child_ids"`
ParentID int `json:"parent_id"`
} `json:"offices"`
} `json:"jobs"`
Meta struct {
Total int `json:"total"`
} `json:"meta"`
}
Jobs describes an organization's job listings.
Click to show internal directories.
Click to hide internal directories.